/*
	bladedll.h

        +++++++++++++++++++++++++++
	+   Blade's Encoder DLL   +
	+++++++++++++++++++++++++++
        -------------------------------------------------------
	- Version 2.090(23 June 2000) - Przemyslaw Dobrowolski -
	-------------------------------------------------------
        Ported to OS/2 DLL

        -------------------------------------------------------
	- Version 1.00 (7 November 1998) - Jukka Poikolainen  -
	-------------------------------------------------------
	Initial version

*/

#ifndef ___BLADEDLL_H_INCLUDED___

#include <os2.h>

#define ___BLADEDLL_H_INCLUDED___

#ifdef __WATCOMC__
#pragma pack(push)
#endif
#pragma pack(1)

/* encoding formats */
#define		BE_CONFIG_MP3			0										

/* type definitions */
typedef		unsigned long			HBE_STREAM;
typedef		HBE_STREAM			*PHBE_STREAM;
typedef		unsigned long			BE_ERR;

/* error codes */

#define		BE_ERR_SUCCESSFUL				0x00000000
#define		BE_ERR_INVALID_FORMAT				0x00000001
#define		BE_ERR_INVALID_FORMAT_PARAMETERS		0x00000002
#define		BE_ERR_NO_MORE_HANDLES				0x00000003
#define		BE_ERR_INVALID_HANDLE				0x00000004

/* other constants */
#define		BE_MAX_HOMEPAGE			256

/* format specific variables */
#define		BE_MP3_MODE_STEREO		0
#define		BE_MP3_MODE_DUALCHANNEL		2
#define		BE_MP3_MODE_MONO		3

typedef struct	{
	LONG 	dwConfig;			// BE_CONFIG_XXXXX
								// Currently only BE_CONFIG_MP3 is supported
	union	{
		struct	{
			LONG 	dwSampleRate;	// 48000, 44100 and 32000 allowed
			BYTE	byMode;			// BE_MP3_MODE_STEREO, BE_MP3_MODE_DUALCHANNEL, BE_MP3_MODE_MONO
			LONG 	wBitrate;		// 32, 40, 48, 56, 64, 80, 96, 112, 128, 160, 192, 224, 256 and 320 allowed
			BOOL	bPrivate;		
			BOOL	bCRC;
			BOOL	bCopyright;
			BOOL	bOriginal;
			} mp3;					// BE_CONFIG_MP3
		struct	{
			ULONG	dwSampleRate;
			BYTE	byMode;
			LONG	wBitrate;
			BYTE	byEncodingMethod;
		} aac;
	} format;
} BE_CONFIG, *PBE_CONFIG;


typedef struct	{
	// BladeEnc DLL Version number
	BYTE	byDLLMajorVersion;
	BYTE	byDLLMinorVersion;

	// BladeEnc Engine Version Number
	BYTE	byMajorVersion;
	BYTE	byMinorVersion;

	// DLL Release date
	BYTE	byDay;
	BYTE	byMonth;
	LONG	       wYear;

	// BladeEnc	Homepage URL
	CHAR	zHomepage[BE_MAX_HOMEPAGE + 1];	
} BE_VERSION, *PBE_VERSION;			

#ifdef __WATCOMC__

typedef BE_ERR	_syscall (* BEINITSTREAM)	(PBE_CONFIG, PULONG, PULONG, PHBE_STREAM);
typedef BE_ERR	_syscall (* BEENCODECHUNK)	(HBE_STREAM, ULONG, PSHORT, PBYTE, PULONG);
typedef BE_ERR	_syscall (*BEDEINITSTREAM)	(HBE_STREAM, PBYTE, PULONG);
typedef BE_ERR	_syscall (*BECLOSESTREAM)	(HBE_STREAM);
typedef VOID	_syscall (*BEVERSION)		(PBE_VERSION);
#else

typedef BE_ERR	 (* _System BEINITSTREAM)	(PBE_CONFIG, PULONG, PULONG, PHBE_STREAM);
typedef BE_ERR	 (* _System BEENCODECHUNK)	(HBE_STREAM, ULONG, PSHORT, PBYTE, PULONG);
typedef BE_ERR	 (* _System BEDEINITSTREAM)	(HBE_STREAM, PBYTE, PULONG);
typedef BE_ERR	 (* _System BECLOSESTREAM)	(HBE_STREAM);
typedef VOID	 (* _System BEVERSION)		(PBE_VERSION);

#endif

#define	TEXT_BEINITSTREAM	"beInitStream"
#define	TEXT_BEENCODECHUNK	"beEncodeChunk"
#define	TEXT_BEDEINITSTREAM	"beDeinitStream"
#define	TEXT_BECLOSESTREAM	"beCloseStream"
#define	TEXT_BEVERSION		"beVersion"


/*	

	BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PULONG dwSamples, PULONG dwBufferSize, PHBE_STREAM phbeStream);
	BE_ERR	beEncodeChunk(HBE_STREAM hbeStream, ULONG nSamples, PSHORT pSamples, PBYTE pOutput, PULONG pdwOutput);
	BE_ERR	beDeinitStream(HBE_STREAM hbeStream, PBYTE pOutput, PULONG pdwOutput);
	BE_ERR	beCloseStream(HBE_STREAM hbeStream);
	VOID	beVersion(PBE_VERSION pbeVersion);		

*/

#ifdef __WATCOMC__
#pragma pack(pop)
#else
#pragma pack()
#endif



#endif

